@@ -1,2 +1,2 @@
-from palp.spider.spider import Spider
+from palp.spider.spider_local import LocalSpider
 from palp.spider.spider_distributive import DistributiveSpider
